'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _reactDom = require('react-dom');

var _reactDom2 = _interopRequireDefault(_reactDom);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CLASS_ATTRIBUTE_NAME = 'data-react-class';
var PROPS_ATTRIBUTE_NAME = 'data-react-props';

var WebpackerReact = {
  eventsRegistered: false,
  registeredComponents: {},
  wrapForHMR: null,

  render: function render(node, component) {
    var propsJson = node.getAttribute(PROPS_ATTRIBUTE_NAME);
    var props = propsJson && JSON.parse(propsJson);

    var reactElement = _react2.default.createElement(component, props);
    if (this.wrapForHMR) {
      reactElement = this.wrapForHMR(reactElement);
    }
    _reactDom2.default.render(reactElement, node);
  },

  renderOnHMR: function renderOnHMR(component) {
    var name = component.name;
    this.registeredComponents[name] = component;

    if (!this.wrapForHMR) {
      console.warn('webpack-react: renderOnHMR called but not elements not wrapped for HMR');
    }

    var toMount = document.querySelectorAll('[' + CLASS_ATTRIBUTE_NAME + '=' + name + ']');
    for (var i = 0; i < toMount.length; ++i) {
      var node = toMount[i];

      this.render(node, component);
    }
  },

  registerWrapForHMR: function registerWrapForHMR(wrapForHMR) {
    this.wrapForHMR = wrapForHMR;
  },


  register: function register(component) {
    var name = component.name;

    if (this.registeredComponents[name]) {
      console.warn('webpacker-react: Cant register component, another one with this name is already registered: ' + name);
      return false;
    }

    this.registeredComponents[name] = component;
    return true;
  },

  addEventEventhandlers: function addEventEventhandlers() {
    var _this = this;

    var registeredComponents = this.registeredComponents;

    if (this.eventsRegistered == true) {
      console.warn("webpacker-react: events have already been registered");
      return false;
    }

    document.addEventListener("DOMContentLoaded", function () {
      var toMount = document.querySelectorAll('[' + CLASS_ATTRIBUTE_NAME + ']');

      for (var i = 0; i < toMount.length; ++i) {
        var node = toMount[i];
        var className = node.getAttribute(CLASS_ATTRIBUTE_NAME);
        var component = registeredComponents[className];

        if (component) {
          _this.render(node, component);
        } else {
          console.error('webpacker-react: cant render a component that has not been registered: ' + className);
        }
      }
    });

    this.eventsRegistered = true;
    return true;
  }
};

WebpackerReact.addEventEventhandlers();

exports.default = WebpackerReact;